/*
 * Update the database schema from Sitecore CMS 6.2 to CMS 6.3
 *
 * This script must be executed on all Sitecore databases to upgrade them to the CMS 6.3 database schema.
 */

 -- Uncomment and change the following line if you want to execute the script on a different database 
 --USE [Sitecore_Core]


IF NOT EXISTS(select * from sys.tables where name = 'EventQueue')
BEGIN
	CREATE TABLE [EventQueue]
	(
		[Id] UNIQUEIDENTIFIER NOT NULL,
		[EventType] NVARCHAR(256) NOT NULL,
		[InstanceType] NVARCHAR(256) NOT NULL,
		[InstanceData] NVARCHAR(MAX) NOT NULL,
		[InstanceName] NVARCHAR(128) NOT NULL,
		[RaiseLocally] INT NOT NULL,
		[RaiseGlobally] INT NOT NULL,
		[UserName] NVARCHAR(128) NOT NULL,
		[Sequence] BIGINT IDENTITY(1,1) NOT NULL,
		[Created] DATETIME NOT NULL
	)
	ON [PRIMARY];

	ALTER TABLE [EventQueue]
	ADD CONSTRAINT [DF_EventQueue_Created]
	DEFAULT (GETUTCDATE())
	FOR [Created]
	
	CREATE CLUSTERED INDEX [IX_Sequence] ON [dbo].[EventQueue] ([Created] ASC,[Sequence] ASC)
	ON [PRIMARY]
END

go

--Schema changes in Tasks table
if not exists (select * from sys.columns where name = 'InstanceName' and [object_id] = object_id('Tasks'))
	alter table Tasks add InstanceName nvarchar(128) null

--Make sure all MDFs of Sitecore 6.3 have the same as or more recent schema than MDFs in Sitecore 6.2

if exists(select top 1 * from sys.columns 
where [object_id] = object_id('ArchivedItems') and name = 'Name' and collation_name = 'Danish_Norwegian_CI_AS')
	alter table ArchivedItems alter column Name nvarchar(256) not null
	
GO

IF NOT EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[dbo].[Blobs]') AND name = N'ndxBlobId')
	CREATE NONCLUSTERED INDEX [ndxBlobId] ON [Blobs] ([BlobId] ASC)
	WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

IF EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[dbo].[Descendants]') AND name = N'Ancestor')
	DROP INDEX Ancestor on Descendants

GO

if exists(select top 1 * from sys.columns 
where [object_id] = object_id('Items') and name = 'Name' and collation_name = 'Danish_Norwegian_CI_AS')
begin
	DROP INDEX ndxName on Items

	alter table Items alter column Name nvarchar(256)not null
	
	CREATE NONCLUSTERED INDEX [ndxName] ON [Items] ([Name] ASC)WITH 
		(PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
end 
	
GO

IF EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[dbo].[SharedFields]') AND name = N'ndxItemID')
	DROP INDEX ndxItemID on SharedFields

GO

IF EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[dbo].[UnversionedFields]') AND name = N'ndxItemID')
	DROP INDEX ndxItemID on UnversionedFields
GO

IF EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[dbo].[UnversionedFields]') AND name = N'ndxLookup')
	DROP INDEX ndxLookup on UnversionedFields
GO

IF EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[dbo].[VersionedFields]') AND name = N'ndxItemID')
	DROP INDEX ndxItemID on VersionedFields
GO

IF EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[dbo].[VersionedFields]') AND name = N'ndxLookup')
	DROP INDEX ndxLookup on VersionedFields
GO

if exists(select top 1 * from sys.foreign_keys where name = 'FK__aspnet_Me__Appli__2759D01A' and parent_object_id=object_id('aspnet_Membership'))
	alter table aspnet_membership drop FK__aspnet_Me__Appli__2759D01A
	
go

if exists(select top 1 * from sys.foreign_keys where name = 'FK__aspnet_Me__UserI__284DF453' and parent_object_id=object_id('aspnet_Membership'))
	alter table aspnet_membership drop FK__aspnet_Me__UserI__284DF453
	
go

if exists(select top 1 * from sys.foreign_keys where name = 'FK__aspnet_Pa__Appli__58F12BAE' and parent_object_id=object_id('aspnet_Paths'))
	alter table aspnet_Paths drop FK__aspnet_Pa__Appli__58F12BAE
	
go

if exists(select top 1 * from sys.foreign_keys where name = 'FK__aspnet_Pe__PathI__5EAA0504' and parent_object_id=object_id('aspnet_PersonalizationAllUsers'))
	alter table aspnet_PersonalizationAllUsers drop FK__aspnet_Pe__PathI__5EAA0504
	
go

if exists(select top 1 * from sys.foreign_keys where name = 'FK__aspnet_Pe__PathI__627A95E8' and parent_object_id=object_id('aspnet_PersonalizationPerUser'))
	alter table aspnet_PersonalizationPerUser drop FK__aspnet_Pe__PathI__627A95E8
	
go

if exists(select top 1 * from sys.foreign_keys where name = 'FK__aspnet_Pe__UserI__636EBA21' and parent_object_id=object_id('aspnet_PersonalizationPerUser'))
	alter table aspnet_PersonalizationPerUser drop FK__aspnet_Pe__UserI__636EBA21
	
go

if exists(select top 1 * from sys.foreign_keys where name = 'FK__aspnet_Pr__UserI__3C54ED00' and parent_object_id=object_id('aspnet_Profile'))
	alter table aspnet_Profile drop FK__aspnet_Pr__UserI__3C54ED00
	
go

if exists(select top 1 * from sys.foreign_keys where name = 'FK__aspnet_Ro__Appli__45DE573A' and parent_object_id=object_id('aspnet_Roles'))
	alter table aspnet_Roles drop FK__aspnet_Ro__Appli__45DE573A
	
go

if exists(select top 1 * from sys.foreign_keys where name = 'FK__aspnet_Us__Appli__17236851' and parent_object_id=object_id('aspnet_Users'))
	alter table aspnet_Users drop FK__aspnet_Us__Appli__17236851
	
go

if exists(select top 1 * from sys.foreign_keys where name = 'FK__aspnet_Us__RoleI__4AA30C57' and parent_object_id=object_id('aspnet_UsersInRoles'))
	alter table aspnet_UsersInRoles drop FK__aspnet_Us__RoleI__4AA30C57
	
go

if exists(select top 1 * from sys.foreign_keys where name = 'FK__aspnet_Us__UserI__49AEE81E' and parent_object_id=object_id('aspnet_UsersInRoles'))
	alter table aspnet_UsersInRoles drop FK__aspnet_Us__UserI__49AEE81E
	
go

if exists(select top 1 * from sys.indexes where [object_id] = object_id('Blobs') and name = 'ndxBlobId' and allow_page_locks = 1)
	alter index ndxBlobId on Blobs set (allow_page_locks = ON)

go
